@@ -1,5 +1,5 @@
 import json
-from typing import Any, Type, Union
+from typing import Any, Dict, Union
 
 from django.http.response import JsonResponse
 
@@ -17,24 +17,24 @@ class BaseApiResponse(JsonResponse):
 
     def __init__(
         self,
-        data: Union[dict, str] = None,
-        errno: int = None,
+        data: Union[Dict, str] = None,
+        code: int = None,
         message: str = None,
         **kwargs: Any
     ):
-        if errno:
+        if code:
             message = message or UNKNOWN_ERROR_MSG
         else:
             message = SUCCESS_MESSAGE
-            errno = ERRNO_SUCCESS
+            code = ERRNO_SUCCESS
 
-        _data: Union[dict, str] = {
-            "code": errno,
+        _data: Union[Dict, str] = {
+            "code": code,
             "message": message,
             "data": data if data is not None else {},
         }
-        _encoder: Type[json.JSONEncoder] = EasyJSONEncoder
-        super().__init__(data=_data, encoder=_encoder, **kwargs)
+
+        super().__init__(data=_data, encoder=EasyJSONEncoder, **kwargs)
 
     @property
     def json_data(self) -> Any:
@@ -43,7 +43,7 @@ class BaseApiResponse(JsonResponse):
         """
         return json.loads(self.content)
 
-    def update_content(self, data: dict) -> None:
+    def update_content(self, data: Dict) -> None:
         """
         Update content with new data
         """
