@@ -26,6 +26,14 @@ def user(db) -> User:
 def easy_api_client(user) -> EasyTestClient:
     orig_func = copy.deepcopy(JWTAuthAsync.__call__)
 
+    orig_has_perm_fuc = copy.deepcopy(user.has_perm)
+
+    def mock_has_perm_true(*args, **kwargs):
+        return True
+
+    def mock_has_perm_false(*args, **kwargs):
+        return False
+
     async def mock_func(self, request):
         setattr(request, "user", user)
         return True
@@ -36,11 +44,19 @@ def easy_api_client(user) -> EasyTestClient:
         api: CrudAPIController,
         is_staff: bool = False,
         is_superuser: bool = False,
+        has_perm: bool = False,
     ):
         setattr(user, "is_staff", is_staff)
         setattr(user, "is_superuser", is_superuser)
+        if is_superuser:
+            setattr(user, "is_staff", True)
+        if has_perm:
+            setattr(user, "has_perm", mock_has_perm_true)
+        else:
+            setattr(user, "has_perm", mock_has_perm_false)
         client = EasyTestClient(api, auth=jwt_auth_async)
         return client
 
     yield create_client
     setattr(JWTAuthAsync, "__call__", orig_func)
+    setattr(user, "has_perm", orig_has_perm_fuc)
